@@ -27,13 +27,13 @@ email                : chubinger@irrsinnig.org
 #include <kurl.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kconfig.h>
-#include <ktempfile.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
+#include <tdetempfile.h>
+#include <tdemessagebox.h>
 #include <kiconloader.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <ktar.h>
 #include <kmdcodec.h>
 
@@ -205,7 +205,7 @@ void KMFIPTInstaller::cmdRunFW() {
 		}
 		
 		TQString cmd = "bash " + temp_file->name() + " -v start";
-		// KProcessWrapper::instance()->slotStartLocalJob( "startfirewall", cmd, true, true );
+		// TDEProcessWrapper::instance()->slotStartLocalJob( "startfirewall", cmd, true, true );
 		setOutputWidget( execWidget() );
 		execWidget()->runCmd( cmd, Constants::StartFirewallJob_Name, i18n("Start Firewall on %1").arg( rulesetDoc()->target()->toFriendlyString() ), true );
 		showOutput();
@@ -246,16 +246,16 @@ void KMFIPTInstaller::cmdRunFW() {
 		
 		generateInstallerPackage( rulesetDoc()->target() );
 		TQString cmd = "cd /tmp/; sh ./kmfpackage.kmfpkg -q --start";
-		KProcessWrapper::instance()->slotStartRemoteJob( Constants::StartFirewallJob_Name, cmd, rulesetDoc()->target() );
+		TDEProcessWrapper::instance()->slotStartRemoteJob( Constants::StartFirewallJob_Name, cmd, rulesetDoc()->target() );
 	
-		if ( KProcessWrapper::instance()->exitStatus() != 0 ) {
-			kdDebug() << "ERROR:" << KProcessWrapper::instance()->stdErr() << endl;
-			KMessageBox::error( 0, KProcessWrapper::instance()->stdCombined() );
+		if ( TDEProcessWrapper::instance()->exitStatus() != 0 ) {
+			kdDebug() << "ERROR:" << TDEProcessWrapper::instance()->stdErr() << endl;
+			KMessageBox::error( 0, TDEProcessWrapper::instance()->stdCombined() );
 			return;	 
 		}
 			
 		setOutputWidget( execWidget() );
-		execWidget()->setText( KProcessWrapper::instance()->stdOut(), i18n("Start Firewall on %1").arg( rulesetDoc()->target()->toFriendlyString() )  );
+		execWidget()->setText( TDEProcessWrapper::instance()->stdOut(), i18n("Start Firewall on %1").arg( rulesetDoc()->target()->toFriendlyString() )  );
 		showOutput();
 		checkStatus();
 	}
@@ -294,16 +294,16 @@ void KMFIPTInstaller::cmdStopFW() {
 		
 		generateInstallerPackage( rulesetDoc()->target() );
 		TQString cmd = "cd /tmp/; sh ./kmfpackage.kmfpkg -q --stop";
-		KProcessWrapper::instance()->slotStartRemoteJob( Constants::StopFirewallJob_Name, cmd, rulesetDoc()->target() );
+		TDEProcessWrapper::instance()->slotStartRemoteJob( Constants::StopFirewallJob_Name, cmd, rulesetDoc()->target() );
 
-		if ( KProcessWrapper::instance()->exitStatus() != 0 ) {
-			kdDebug() << "ERROR:" << KProcessWrapper::instance()->stdErr() << endl;
-			KMessageBox::error( 0, KProcessWrapper::instance()->stdCombined() );
+		if ( TDEProcessWrapper::instance()->exitStatus() != 0 ) {
+			kdDebug() << "ERROR:" << TDEProcessWrapper::instance()->stdErr() << endl;
+			KMessageBox::error( 0, TDEProcessWrapper::instance()->stdCombined() );
 			return;	 
 		}
 			
 		setOutputWidget( execWidget() );
-		execWidget()->setText( KProcessWrapper::instance()->stdOut(), i18n("Stop Firewall on %1").arg( rulesetDoc()->target()->toFriendlyString() )  );
+		execWidget()->setText( TDEProcessWrapper::instance()->stdOut(), i18n("Stop Firewall on %1").arg( rulesetDoc()->target()->toFriendlyString() )  );
 		showOutput();
 		checkStatus();
 	}
@@ -322,7 +322,7 @@ void KMFIPTInstaller::cmdShowRunningConfig( const TQString& para ) {
 	}
 	
 	if( rulesetDoc()->target()->isLocalExecuteTarget() ) {
-		// KProcessWrapper::instance()->slotStartLocalJob( "show_config", cmd, true, true );
+		// TDEProcessWrapper::instance()->slotStartLocalJob( "show_config", cmd, true, true );
 		setOutputWidget( execWidget() );
 		execWidget()->runCmd( cmd,Constants::ShowConfigJob_Name,  i18n("Show Table %1 on %2").arg( para ).arg( rulesetDoc()->target()->toFriendlyString() ), true );
 		showOutput();
@@ -331,16 +331,16 @@ void KMFIPTInstaller::cmdShowRunningConfig( const TQString& para ) {
 		setOutputWidget( execWidget() );
 		execWidget()->setText( i18n("Please wait while the scripts are uploaded and executed..."), i18n("Install Firewall on %1").arg( rulesetDoc()->target()->toFriendlyString() )  );
 		showOutput();
-		KProcessWrapper::instance()->slotStartRemoteJob( Constants::ShowConfigJob_Name, cmd, rulesetDoc()->target() );
+		TDEProcessWrapper::instance()->slotStartRemoteJob( Constants::ShowConfigJob_Name, cmd, rulesetDoc()->target() );
 	
-		if ( KProcessWrapper::instance()->exitStatus() != 0 ) {
-			kdDebug() << "ERROR:" << KProcessWrapper::instance()->stdErr() << endl;
-			KMessageBox::error( 0, KProcessWrapper::instance()->stdCombined() );
+		if ( TDEProcessWrapper::instance()->exitStatus() != 0 ) {
+			kdDebug() << "ERROR:" << TDEProcessWrapper::instance()->stdErr() << endl;
+			KMessageBox::error( 0, TDEProcessWrapper::instance()->stdCombined() );
 			return;	 
 		}
 		
 		setOutputWidget( execWidget() );
-		execWidget()->setText( KProcessWrapper::instance()->stdOut(), i18n("Show Table %1 on %2").arg( para ).arg( rulesetDoc()->target()->toFriendlyString() )  );
+		execWidget()->setText( TDEProcessWrapper::instance()->stdOut(), i18n("Show Table %1 on %2").arg( para ).arg( rulesetDoc()->target()->toFriendlyString() )  );
 		showOutput();
 	}
 }
@@ -360,13 +360,13 @@ void KMFIPTInstaller::cmdInstallFW() {
 	}
 	
 	if ( rulesetDoc()->target()->isLocalExecuteTarget() ) {
-		KURL url ( KGlobal::dirs() ->findResource( "appdata", "scripts/installer/linux/kmfinstall.sh" ));
+		KURL url ( TDEGlobal::dirs() ->findResource( "appdata", "scripts/installer/linux/kmfinstall.sh" ));
 		TQString installscript = url.path();
 
 		if ( installscript.isEmpty() ) {
 			TQString msg = i18n( "<p>Unable to find install script <b>kmfinstall.sh</b>"
 			                    "<p>Please check your installation. Usually this script is installed in "
-			                    "$KDEDIR/share/apps/kmyfirewall/scripts/installer/linux"
+			                    "$TDEDIR/share/apps/kmyfirewall/scripts/installer/linux"
 			                    "<p>Unable to install the firewall without this script." );
 			TQString cap = "KMFIPTInstaller";
 			KMessageBox::error( 0, msg, cap );
@@ -434,16 +434,16 @@ void KMFIPTInstaller::cmdInstallFW() {
 			
 		generateInstallerPackage( rulesetDoc()->target() );
 		TQString cmd = "cd /tmp/; sh ./kmfpackage.kmfpkg -q --install";
-		KProcessWrapper::instance()->slotStartRemoteJob( Constants::InstallFirewallJob_Name, cmd, rulesetDoc()->target() );
+		TDEProcessWrapper::instance()->slotStartRemoteJob( Constants::InstallFirewallJob_Name, cmd, rulesetDoc()->target() );
 	
-		if ( KProcessWrapper::instance()->exitStatus() != 0 ) {
-			kdDebug() << "ERROR:" << KProcessWrapper::instance()->stdErr() << endl;
-			KMessageBox::error( 0, KProcessWrapper::instance()->stdCombined() );
+		if ( TDEProcessWrapper::instance()->exitStatus() != 0 ) {
+			kdDebug() << "ERROR:" << TDEProcessWrapper::instance()->stdErr() << endl;
+			KMessageBox::error( 0, TDEProcessWrapper::instance()->stdCombined() );
 			return;	 
 		}
 		
 		setOutputWidget( execWidget() );
-		execWidget()->setText( KProcessWrapper::instance()->stdOut(), i18n("Install Firewall on %1").arg( rulesetDoc()->target()->toFriendlyString() )  );
+		execWidget()->setText( TDEProcessWrapper::instance()->stdOut(), i18n("Install Firewall on %1").arg( rulesetDoc()->target()->toFriendlyString() )  );
 		showOutput();
 		checkStatus();	
 	}
@@ -463,13 +463,13 @@ void KMFIPTInstaller::cmdUninstallFW() {
 		
 		
 	if ( rulesetDoc()->target()->isLocalExecuteTarget() ) {
-		KURL url (KGlobal::dirs() ->findResource( "appdata", "scripts/installer/linux/kmfinstall.sh" ));
+		KURL url (TDEGlobal::dirs() ->findResource( "appdata", "scripts/installer/linux/kmfinstall.sh" ));
 		TQString installscript = url.path();
 
 		if ( installscript.isEmpty() ) {
 			const TQString & msg = i18n( "<p>Unable to find uninstall script <b>kmfinstall.sh</b>"
 			                            "<p>Please check your installation. Usually this script is installed in "
-			                            "$KDEDIR/share/apps/kmyfirewall/scripts/installer/linux"
+			                            "$TDEDIR/share/apps/kmyfirewall/scripts/installer/linux"
 			                            "<p>Unable to uninstall the firewall without this script." );
 			const TQString& cap = "KMFIPTInstaller";
 			KMessageBox::error( 0, msg, cap );
@@ -516,7 +516,7 @@ void KMFIPTInstaller::cmdUninstallFW() {
 			systemtype = "sysv";
 
 		TQString cmd = "bash " + installscript + " uninstall " + systemtype + " " + conf->initPath() + " " + conf->rcDefaultPath();
-		// KProcessWrapper::instance()->slotStartLocalJob( "uninstallfirewall", cmd, true, true );
+		// TDEProcessWrapper::instance()->slotStartLocalJob( "uninstallfirewall", cmd, true, true );
 	
 		setOutputWidget( execWidget() );
 		execWidget()->runCmd( cmd, Constants::UninstallFirewallJob_Name,  i18n("Uninstall Firewall on %1").arg( rulesetDoc()->target()->toFriendlyString() ), true );
@@ -530,16 +530,16 @@ void KMFIPTInstaller::cmdUninstallFW() {
 			
 		generateInstallerPackage( rulesetDoc()->target() );
 		TQString cmd = "cd /tmp/; sh ./kmfpackage.kmfpkg -q --uninstall";
-		KProcessWrapper::instance()->slotStartRemoteJob( Constants::UninstallFirewallJob_Name, cmd, rulesetDoc()->target() );
+		TDEProcessWrapper::instance()->slotStartRemoteJob( Constants::UninstallFirewallJob_Name, cmd, rulesetDoc()->target() );
 		
-		if ( KProcessWrapper::instance()->exitStatus() != 0 ) {
-			kdDebug() << "ERROR:" << KProcessWrapper::instance()->stdErr() << endl;
-			KMessageBox::error( 0, KProcessWrapper::instance()->stdCombined() );
+		if ( TDEProcessWrapper::instance()->exitStatus() != 0 ) {
+			kdDebug() << "ERROR:" << TDEProcessWrapper::instance()->stdErr() << endl;
+			KMessageBox::error( 0, TDEProcessWrapper::instance()->stdCombined() );
 			return;	 
 		}
 		
 		setOutputWidget( execWidget() );
-		execWidget()->setText( KProcessWrapper::instance()->stdOut(), i18n("Uninstall Firewall on %1").arg( rulesetDoc()->target()->toFriendlyString() )  );
+		execWidget()->setText( TDEProcessWrapper::instance()->stdOut(), i18n("Uninstall Firewall on %1").arg( rulesetDoc()->target()->toFriendlyString() )  );
 		showOutput();
 		checkStatus();
 	}	
@@ -870,7 +870,7 @@ void KMFIPTInstaller::generateInstallerPackage( KMFTarget* tg ) {
 		if ( url.fileName().isEmpty() )
 			return;
 		
-		if ( KIO::NetAccess::exists( url, false, KApplication::kApplication()->mainWidget() ) ) {
+		if ( TDEIO::NetAccess::exists( url, false, TDEApplication::kApplication()->mainWidget() ) ) {
 			TQDateTime now = TQDateTime::currentDateTime();
 			
 			TQString backUp;
@@ -885,12 +885,12 @@ void KMFIPTInstaller::generateInstallerPackage( KMFTarget* tg ) {
 			backUp.append( now.toString( "dd.MM.yyyy.hh:mm:ss" ) );
 			
 			
-			KIO::NetAccess::file_move( url, newUrl, 700, true, true, KApplication::kApplication()->mainWidget() );
-			KIO::NetAccess::fish_execute( remDir, "chmod 400 /tmp/" + backFileName, KApplication::kApplication()->mainWidget() );
+			TDEIO::NetAccess::file_move( url, newUrl, 700, true, true, TDEApplication::kApplication()->mainWidget() );
+			TDEIO::NetAccess::fish_execute( remDir, "chmod 400 /tmp/" + backFileName, TDEApplication::kApplication()->mainWidget() );
 		}
 		
 		inst2->generateInstallerPackage( tg, url );
-		KIO::NetAccess::fish_execute( remDir, "chmod 700 /tmp/kmfpackage.kmfpkg", KApplication::kApplication()->mainWidget() );
+		TDEIO::NetAccess::fish_execute( remDir, "chmod 700 /tmp/kmfpackage.kmfpkg", TDEApplication::kApplication()->mainWidget() );
 	}
 }
 
@@ -908,11 +908,11 @@ void KMFIPTInstaller::generateInstallerPackage( KMFTarget* target, const KURL& p
 	KTempFile *kmf_pkg_intsall = new KTempFile();	
 	KTempFile *kmf_install_package = new KTempFile();
 	
-	KURL readme_url ( KGlobal::dirs() ->findResource( "appdata", "README.InstallerPackage.txt" ));
+	KURL readme_url ( TDEGlobal::dirs() ->findResource( "appdata", "README.InstallerPackage.txt" ));
 	if ( readme_url.path().isEmpty() ) {
 		TQString msg = i18n( "<p>Unable to find the package README script <b>README.InstallerPackage.txt</b>"
 				"<p>Please check your installation. Usually this file is installed in "
-				"$KDEDIR/share/apps/kmyfirewall/"
+				"$TDEDIR/share/apps/kmyfirewall/"
 				"<p>The package will be built without the README file." );
 		TQString cap = "KMFIPTInstaller";
 		KMessageBox::error( 0, msg, cap );
@@ -921,11 +921,11 @@ void KMFIPTInstaller::generateInstallerPackage( KMFTarget* target, const KURL& p
 	kdDebug() << "found readme script: " << readme_url.path() << endl;	
 	
 	
-	KURL kmfinstall_url ( KGlobal::dirs() ->findResource( "appdata", "scripts/installer/" + target->config()->oS() + "/kmfinstall.sh" ));
+	KURL kmfinstall_url ( TDEGlobal::dirs() ->findResource( "appdata", "scripts/installer/" + target->config()->oS() + "/kmfinstall.sh" ));
 	if ( kmfinstall_url.path().isEmpty() ) {
 		TQString msg = i18n( "<p>Unable to find install script <b>kmfinstall.sh</b>"
 				"<p>Please check your installation. Usually this script is installed in "
-				"$KDEDIR/share/apps/kmyfirewall/scripts/installer/%1"
+				"$TDEDIR/share/apps/kmyfirewall/scripts/installer/%1"
 				"<p>Unable to install the firewall without this script."
                                 ).arg(target->config()->oS());
 		TQString cap = "KMFIPTInstaller";
@@ -938,11 +938,11 @@ void KMFIPTInstaller::generateInstallerPackage( KMFTarget* target, const KURL& p
 
 	
 	
-	KURL kmfpgkinstall_url ( KGlobal::dirs() ->findResource( "appdata", "scripts/installer/" + target->config()->oS() + "/kmfpkginstall.sh" ));
+	KURL kmfpgkinstall_url ( TDEGlobal::dirs() ->findResource( "appdata", "scripts/installer/" + target->config()->oS() + "/kmfpkginstall.sh" ));
 	if ( kmfpgkinstall_url.path().isEmpty() ) {
 		TQString msg = i18n( "<p>Unable to find install script <b>kmfinstall.sh</b>"
 				"<p>Please check your installation. Usually this script is installed in "
-				"$KDEDIR/share/apps/kmyfirewall/scripts/installer/%1"
+				"$TDEDIR/share/apps/kmyfirewall/scripts/installer/%1"
 				"<p>Unable to install the firewall without this script."
                                 ).arg(target->config()->oS());
 		TQString cap = "KMFIPTInstaller";
@@ -954,11 +954,11 @@ void KMFIPTInstaller::generateInstallerPackage( KMFTarget* target, const KURL& p
 	parseFileHeaders( kmfpgkinstall_url.path(), kmf_pkg_intsall->name() );
 	
 	
-	KURL kmf_install_package_url ( KGlobal::dirs() ->findResource( "appdata", "scripts/installer/" + target->config()->oS() + "/installpackage.sh" ));
+	KURL kmf_install_package_url ( TDEGlobal::dirs() ->findResource( "appdata", "scripts/installer/" + target->config()->oS() + "/installpackage.sh" ));
 	if ( kmf_install_package_url.path().isEmpty() ) {
 		TQString msg = i18n( "<p>Unable to find install package script <b>installpackage.sh</b>"
 				"<p>Please check your installation. Usually this script is installed in "
-				"$KDEDIR/share/apps/kmyfirewall/scripts/installer/%1"
+				"$TDEDIR/share/apps/kmyfirewall/scripts/installer/%1"
 				"<p>Unable to install the firewall without this script."
                                 ).arg(target->config()->oS());
 		TQString cap = "KMFIPTInstaller";
@@ -1094,8 +1094,8 @@ void KMFIPTInstaller::generateInstallerPackage( KMFTarget* target, const KURL& p
 	
 	
 	
-	// KIO::NetAccess::upload( packageArch->name(), packageURL, KApplication::kApplication()->mainWidget() );
-	KIO::NetAccess::upload( kmf_install_package->name(), packageURL, KApplication::kApplication()->mainWidget() );
+	// TDEIO::NetAccess::upload( packageArch->name(), packageURL, TDEApplication::kApplication()->mainWidget() );
+	TDEIO::NetAccess::upload( kmf_install_package->name(), packageURL, TDEApplication::kApplication()->mainWidget() );
 	
 	kdDebug() << "Wrote  package: " <<  packageURL.prettyURL()  << endl; 
 
@@ -1120,29 +1120,29 @@ void KMFIPTInstaller::generateInstallerPackage( KMFTarget* target, const KURL& p
 
 void KMFIPTInstaller::loadIcons() {
 	kdDebug() << "void KMFIPTInstaller::loadIcons()" << endl;
-	KIconLoader *loader = KGlobal:: iconLoader();
+	TDEIconLoader *loader = TDEGlobal:: iconLoader();
 	TQString icon_name;
 	icon_name = "encrypted";
-	icon_run = loader->loadIcon( icon_name, KIcon::Toolbar );
+	icon_run = loader->loadIcon( icon_name, TDEIcon::Toolbar );
 
 	icon_name = "decrypted";
-	icon_stop = loader->loadIcon( icon_name, KIcon::Toolbar );
+	icon_stop = loader->loadIcon( icon_name, TDEIcon::Toolbar );
 
 	icon_name = "openterm";
-	icon_show = loader->loadIcon( icon_name, KIcon::Toolbar );
+	icon_show = loader->loadIcon( icon_name, TDEIcon::Toolbar );
 }
 
 // It's usually safe to leave the factory code alone.. with the
-// notable exception of the KAboutData data
-#include <kaboutdata.h>
-#include <klocale.h>
+// notable exception of the TDEAboutData data
+#include <tdeaboutdata.h>
+#include <tdelocale.h>
 
-// KInstance* KMFIPTablesCompilerFactory::s_instance = 0L;
-// KAboutData* KMFIPTablesCompilerFactory::s_about = 0L;
+// TDEInstance* KMFIPTablesCompilerFactory::s_instance = 0L;
+// TDEAboutData* KMFIPTablesCompilerFactory::s_about = 0L;
 
 KMFIPTInstallerFactory::KMFIPTInstallerFactory( TQObject* parent, const char* name )
 		: KLibFactory( parent, name ) {
-// 	s_instance = new KInstance( "KMFIPTablesCompilerFactory" );
+// 	s_instance = new TDEInstance( "KMFIPTablesCompilerFactory" );
 }
 
 TQObject* KMFIPTInstallerFactory::createObject( TQObject* parent, const char* name,
@@ -1153,9 +1153,9 @@ TQObject* KMFIPTInstallerFactory::createObject( TQObject* parent, const char* na
 }
 
 
-// KInstance* KMFIPTablesCompilerFactory::instance() {
+// TDEInstance* KMFIPTablesCompilerFactory::instance() {
 // 	if ( !s_instance ) {
-// 		s_instance = new KInstance( "KMFIPTablesCompilerFactory" );
+// 		s_instance = new TDEInstance( "KMFIPTablesCompilerFactory" );
 // 	}
 // 	return s_instance;
 // }
