@@ -23,28 +23,28 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001-2004
 #include <tqlayout.h>
 
 // KDE includes
-#include <kapplication.h>
-#include <kaction.h>
-#include <kaccel.h>
+#include <tdeapplication.h>
+#include <tdeaction.h>
+#include <tdeaccel.h>
 #include <kstdaction.h>
 #include <kstandarddirs.h>
-#include <kfiledialog.h>
-#include <klocale.h>
-#include <kmenubar.h>
+#include <tdefiledialog.h>
+#include <tdelocale.h>
+#include <tdemenubar.h>
 #include <kprocess.h>
 #include <kdebug.h>
 #include <dcopclient.h>
 #include <kstatusbar.h>
-#include <kpopupmenu.h>
-#include <kglobal.h>
-#include <kmessagebox.h>
+#include <tdepopupmenu.h>
+#include <tdeglobal.h>
+#include <tdemessagebox.h>
 #include <kstdguiitem.h>
-#include <kcmdlineargs.h>
-#include <kio/netaccess.h>
-#include <kfileitem.h>
+#include <tdecmdlineargs.h>
+#include <tdeio/netaccess.h>
+#include <tdefileitem.h>
 #include <klibloader.h>
 #include <ktextedit.h>
-#include <kparts/partmanager.h>
+#include <tdeparts/partmanager.h>
 #include <kpushbutton.h>
 #include <kedittoolbar.h>
 
@@ -95,13 +95,13 @@ KMyFirewall::KMyFirewall( TQWidget* parent, const char *name ) : KMFMainWindow(
 	KMFUndoEngine::instance()->setKMFInterface( this );
 	KMFTransactionLog::instance();
 	
-/*	childproc = new KProcess();
+/*	childproc = new TDEProcess();
 	
-	connect( childproc, TQT_SIGNAL( processExited( KProcess* ) ), TQT_TQOBJECT(this), TQT_SLOT( slotProcessExited( KProcess* ) ) ) ;
+	connect( childproc, TQT_SIGNAL( processExited( TDEProcess* ) ), TQT_TQOBJECT(this), TQT_SLOT( slotProcessExited( TDEProcess* ) ) ) ;
 	
-	connect( childproc, TQT_SIGNAL( receivedStdout( KProcess*, char*, int ) ), TQT_TQOBJECT(this), TQT_SLOT( slotReceivedOutput( KProcess*, char*, int ) ) );
+	connect( childproc, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), TQT_TQOBJECT(this), TQT_SLOT( slotReceivedOutput( TDEProcess*, char*, int ) ) );
 	
-	connect( childproc, TQT_SIGNAL( receivedStderr( KProcess*, char*, int ) ), TQT_TQOBJECT(this), TQT_SLOT( slotReceivedError( KProcess*, char*, int ) ) );*/
+	connect( childproc, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ), TQT_TQOBJECT(this), TQT_SLOT( slotReceivedError( TDEProcess*, char*, int ) ) );*/
 	
 	
 	
@@ -169,7 +169,7 @@ KMyFirewall::~KMyFirewall() {}
 //############ Parse CommandLine #####################
 void KMyFirewall::parseCommandLineArgs() {
 	kdDebug() << "############ Parse CommandLine ###############" << endl;
-	KCmdLineArgs * args = KCmdLineArgs::parsedArgs();
+	TDECmdLineArgs * args = TDECmdLineArgs::parsedArgs();
 	
 	
 
@@ -299,7 +299,7 @@ void KMyFirewall::initActions() {
 	kdDebug() << "Init Actions..." << endl;
 	// Custom Actions
 
-	actionEditDocInfo = new KAction( i18n( "&Edit Document Information" ), "edit", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotEditDocInfo() ), actionCollection(), "edit_doc_info" );
+	actionEditDocInfo = new TDEAction( i18n( "&Edit Document Information" ), "edit", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotEditDocInfo() ), actionCollection(), "edit_doc_info" );
 
 	// KStdAction
 	actionNew = KStdAction::openNew( TQT_TQOBJECT(this), TQT_SLOT( slotFileNew() ),
@@ -327,16 +327,16 @@ void KMyFirewall::initActions() {
 	actionRedo = KStdAction::redo( TQT_TQOBJECT(this), TQT_SLOT( slotRedo() ),
 	                               actionCollection(), "redo" );
 
-	actionExportTargetConfig = new KAction( i18n( "&Export Target Configuration..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotExportTargetConfig() ),
+	actionExportTargetConfig = new TDEAction( i18n( "&Export Target Configuration..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotExportTargetConfig() ),
 	                                  actionCollection(), "export_tagret_config" );
 	
-	actionImportTargetConfig = new KAction( i18n( "&Import Target Configuration..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotImportTargetConfig() ), 
+	actionImportTargetConfig = new TDEAction( i18n( "&Import Target Configuration..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotImportTargetConfig() ), 
 	                                  actionCollection(), "import_tagret_config" );
 	
-	actionShowTransactionLog = new KAction( i18n( "&Show Transaction Log..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotShowTransactionLog() ),
+	actionShowTransactionLog = new TDEAction( i18n( "&Show Transaction Log..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotShowTransactionLog() ),
 	                                  actionCollection(), "show_transaction_log" );
 	
-	actionLoadTemplate = new KAction( i18n( "&Load Template..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotLoadTemplate() ),
+	actionLoadTemplate = new TDEAction( i18n( "&Load Template..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotLoadTemplate() ),
 	                                  actionCollection(), "load_template" );
 	                                  
 //	KStdAction::showToolbar( TQT_TQOBJECT(this), TQT_SLOT( toggleToolBar() ) , actionCollection() );
@@ -360,14 +360,14 @@ void KMyFirewall::slotExportTargetConfig() {
 }
 
 void KMyFirewall::slotConfigureToolbars() {
-	saveMainWindowSettings( KGlobal::config(), "KMyFirewall" );
+	saveMainWindowSettings( TDEGlobal::config(), "KMyFirewall" );
 	KEditToolbar dlg( factory() );
 	connect( &dlg, TQT_SIGNAL( newToolbarConfig() ), TQT_TQOBJECT(this), TQT_SLOT( slotNewToolbarConfig() ) );
 	dlg.exec();
 }
 
 void KMyFirewall::slotNewToolbarConfig() {
-	applyMainWindowSettings( KGlobal::config(), "KMyFirewall" );
+	applyMainWindowSettings( TDEGlobal::config(), "KMyFirewall" );
 }
 
 //check for the uid etc...
@@ -395,7 +395,7 @@ bool KMyFirewall::checkRoot() {
 "As the file format used to save the rulesets has changed, "
 "rulesets created with KMyFirewall &lt; 1.0beta1 <b>WILL NOT</b> work, don't even try it!"
 		"</p></qt>" );
-	KConfig* _config = kapp->config();
+	TDEConfig* _config = kapp->config();
 	_config->setGroup( "Notification Messages" );
 	TQString warn = "";
 	warn = _config->readEntry( "compatibility_warning" );
@@ -632,7 +632,7 @@ bool KMyFirewall::prepareForFileOpen( const KURL& url ) {
 		return false;
 	}
 	
-	if ( ! KIO::NetAccess::download( url, xmlfile, KApplication::kApplication()->mainWidget() ) ) {
+	if ( ! TDEIO::NetAccess::download( url, xmlfile, TDEApplication::kApplication()->mainWidget() ) ) {
 		kdDebug() << "Could not download file." << endl;
 		return false;
 	}
@@ -708,7 +708,7 @@ KMFDoc* KMyFirewall::getDocumentLoaderForUrl( const KURL& url, KMFError* err ) {
 	kdDebug() << "void KMyFirewall::getDocumentLoaderForUrl( const KURL&" << url.fileName() << " )" << endl;
 	err->setErrType( KMFError::OK );
 	TQString xmlfile;
-	if ( ! KIO::NetAccess::download( url, xmlfile, KApplication::kApplication()->mainWidget() ) ) {
+	if ( ! TDEIO::NetAccess::download( url, xmlfile, TDEApplication::kApplication()->mainWidget() ) ) {
 		kdDebug() << "Could not download file." << endl;
 		err->setErrType( KMFError::NORMAL );
 		err->setErrMsg( i18n( "<qt>Could not download file %1</qt>" ).arg( url.url() ) );
@@ -768,7 +768,7 @@ KMFDoc* KMyFirewall::getDocumentLoaderForUrl( const KURL& url, KMFError* err ) {
 					network()->setCurrentTarget( tg );
 					updateCaption();
 				kdDebug() << "Returned IPT Doc for target: " << network()->currentTarget()->guiName() << endl;
-				KIO::NetAccess::removeTempFile( xmlfile );
+				TDEIO::NetAccess::removeTempFile( xmlfile );
 				return network()->currentDocAsIPTDoc();
 			}
 		} else if ( root.nodeName() == XML::GenericDoc_DocumentElement ) {
@@ -782,7 +782,7 @@ KMFDoc* KMyFirewall::getDocumentLoaderForUrl( const KURL& url, KMFError* err ) {
 					network()->setCurrentTarget( tg );
 					updateCaption();
 				kdDebug() << "Returned GEneric Doc for target: " << network()->currentTarget()->guiName() << endl;
-				KIO::NetAccess::removeTempFile( xmlfile );
+				TDEIO::NetAccess::removeTempFile( xmlfile );
 				return network()->currentDocAsGenericDoc();
 			}
 		} else if ( root.nodeName() == XML::KMFNetwork_DocumentElement ) {
@@ -802,16 +802,16 @@ KMFDoc* KMyFirewall::getDocumentLoaderForUrl( const KURL& url, KMFError* err ) {
 				
 			
 			kdDebug() << "Returned KMFNetwork " << network()->currentTarget()->guiName() << endl;
-			KIO::NetAccess::removeTempFile( xmlfile );
+			TDEIO::NetAccess::removeTempFile( xmlfile );
 			return network();
 		}
-		KIO::NetAccess::removeTempFile( xmlfile );
+		TDEIO::NetAccess::removeTempFile( xmlfile );
 		kdDebug() << "ERROR: No Loader Found!" << endl;
 		err->setErrType( KMFError::NORMAL );
 		err->setErrMsg( i18n( "<qt>The document is not a valid KMyFirewall document.</qt>" ) );
 		return 0;
 	}
-	KIO::NetAccess::removeTempFile( xmlfile );
+	TDEIO::NetAccess::removeTempFile( xmlfile );
 	err->setErrType( KMFError::NORMAL );
 	err->setErrMsg( i18n( "<qt>Could not download file %1.</qt>" ).arg( url.url() ) );
 	return 0;
@@ -819,9 +819,9 @@ KMFDoc* KMyFirewall::getDocumentLoaderForUrl( const KURL& url, KMFError* err ) {
 
 KMFError* KMyFirewall::parseDocument( const KURL& url ) {
 	kdDebug() << "void KMyFirewall::parseDocument(TQString& file)" << endl;
-	KIO::UDSEntry f_props;
+	TDEIO::UDSEntry f_props;
 	
-	if ( ! KIO::NetAccess::stat( url , f_props, KApplication::kApplication()->mainWidget() ) ) {
+	if ( ! TDEIO::NetAccess::stat( url , f_props, TDEApplication::kApplication()->mainWidget() ) ) {
 		closeSplash();
 		const TQString msg = i18n( "<qt><p>The file <b>%1</b> could not be loaded.</p>"
 		                          "<p>If you are working with files stored on remote computers "
@@ -1018,7 +1018,7 @@ void KMyFirewall::checkStatus() {
 			fclose( sbin1 );
 		} 
 	} else {
-		if ( KIO::NetAccess::exists( network()->currentTarget()->getFishUrl() + "/etc/kmyfirewall", true, KApplication::kApplication()->mainWidget() ) ) {
+		if ( TDEIO::NetAccess::exists( network()->currentTarget()->getFishUrl() + "/etc/kmyfirewall", true, TDEApplication::kApplication()->mainWidget() ) ) {
 			kdDebug() << "Firewall is installed" << endl;
 			isInstalled = true;
 		}
